@@ -26,7 +26,7 @@ class ThreadPool:
     """Pool of threads consuming tasks from a queue"""
 
     def __init__(self, num_threads):
-        self.tasks: Queue = Queue(num_threads)
+        self.tasks: Queue = Queue(-1)
         self.threads: List[Worker] = []
         self.cache_accum = bytearray([0] * 32)
         for _ in range(num_threads):
@@ -195,7 +195,7 @@ class LatchPersistence(DataPersistence):
                 _os.makedirs(dir, exist_ok=True)
                 task_tuples.append((url, local_file_path))
 
-            pool = ThreadPool(-1)
+            pool = ThreadPool(100)
             pool.map(get, task_tuples)
             pool.start()
             pool.wait_completion()
